<template>
    <!-- Change home depending on dog company or enduser -->
    <nav id="navbar-main"
         class="navbar navbar-main navbar-expand-lg bg-white navbar-light position-sticky top-0 shadow d-flex align-items-center justify-content-between">
        <a class="navbar-brand" :href="logoHref">
            <img src="/public/img/DoggyDoggy_app_logo_blackletters.png" alt="DoggyDoggy Logo" width="211" height="45">
        </a>

        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
                aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>

        <div class="collapse navbar-collapse justify-content-center align-items-center" id="navbarNav">
            <div class="d-lg-none">
                <div class="d-flex justify-content-between mb-2">
                    <img src="/public/img/DoggyDoggy_app_logo_blackletters.png" width="150" height="32"
                         alt="Logo van DoggyDoggy">
                    <span class="icon icon-shape rounded-circle icon-shape-white menu-close-button"
                          data-toggle="collapse"
                          data-target="#navbarNav"
                          aria-controls="navbarNav"
                          aria-expanded="false"
                          aria-label="Toggle navigation">
                        <i class="fas fa-times fa-lg text-dark"></i>
                    </span>
                </div>
            </div>


            <ul class="navbar-nav">
                <li v-for="(menuItem, index) in menuItems" class="nav-item"
                    :class="menuItem.submenuItems ? 'dropdown' : ''">
                    <a class="nav-link d-lg-block d-none"
                       :class="menuItem.submenuItems ? 'py-1' : ''"
                       :href="menuItem.href"
                       :id="menuItem.id"
                       :aria-haspopup="!!menuItem.submenuItems"
                       aria-expanded="false">
                        <div class="d-flex align-items-center">
                            <p class="description text-dark mb-0">{{ menuItem.title }}</p>
                            <i v-if="menuItem.submenuItems" class="icon fa fa-caret-down ml-2"></i>
                        </div>
                    </a>

                    <a class="nav-link d-md-block d-lg-none"
                       :class="index === 0 ? 'py-0' : ''"
                       :href="menuItem.href"
                       role="button"
                       :data-toggle="menuItem.submenuItems ? 'dropdown' : ''"
                       aria-haspopup="true"
                       aria-expanded="false">
                        <div class="d-flex align-items-center">
                            <p class="description text-dark mb-0">{{ menuItem.title }}</p>
                            <i v-if="menuItem.submenuItems" class="icon fa fa-caret-down ml-2"></i>
                        </div>
                    </a>

                    <div v-if="menuItem.submenuItems"
                         class="dropdown-menu bg-white"
                         :aria-labelledby="menuItem.id">
                        <template v-for="(subMenuItem, index) in menuItem.submenuItems">
                            <a v-if="subMenuItem.isMainItem"
                               data-main-item="true"
                               class="dropdown-item d-md-block d-lg-none"
                               :href="subMenuItem.href">
                                <i :class="subMenuItem.icon" class="submenu-icon"></i>
                                <p class="description text-dark mb-0" style="display: inline-block">{{ subMenuItem.title
                                    }}
                                </p>
                            </a>

                            <a v-else class="dropdown-item d-flex align-items-center" :href="subMenuItem.href">
                                <i :class="subMenuItem.icon" class="submenu-icon"></i>
                                <p class="description text-dark mb-0">{{ subMenuItem.title }}</p>
                            </a>
                        </template>
                    </div>
                </li>

                <li class="nav-item d-flex d-lg-none">
                    <a href="/loginpage" class="btn btn-outline-primary btn-icon mt-2 flex-fill">
                        <span class="btn-inner--icon">
                            <i class="fas fa-sign-in-alt"></i>
                        </span>

                        <span class="nav-link-inner--text">Inloggen</span>
                    </a>
                </li>

                <li class="nav-item d-flex d-lg-none" v-if="pageType === 'dws'">
                    <a @click="signUpCompany" class="btn btn-success btn-icon mt-2 flex-fill text-white">
                        <span class="btn-inner--icon">
                            <i class="fas fa-paw"></i>
                        </span>

                        <span class="nav-link-inner--text">Meld je aan</span>
                    </a>
                </li>

                <li v-if="pageType" class="nav-item d-flex d-lg-none mt-4">
                    <a :href="pageType === 'dws' ? '/hondeneigenaar' : '/hondenbedrijf'"
                       @click.prevent="changeUserType()" class="ml-1">
                        <p v-if="pageType === 'dws'" class="description mt-3">Ik zoek een hondenbedrijf</p>
                        <p v-else class="description mt-3">Ik heb een hondenbedrijf</p>
                    </a>
                </li>
            </ul>
        </div>

        <ul class="navbar-nav d-none d-lg-flex align-items-center">
            <li v-if="pageType" class="nav-item mr-4">
                <a :href="pageType === 'dws' ? '/hondeneigenaar' : '/hondenbedrijf'" @click.prevent="changeUserType()">
                    <p v-if="pageType === 'dws'" class="description mt-3">Ik zoek een hondenbedrijf</p>
                    <p v-else class="description mt-3">Ik heb een hondenbedrijf</p>
                </a>
            </li>

            <li class="nav-item">
                <a href="/loginpage" class="btn btn-outline-primary btn-icon">
                    <span class="btn-inner--icon">
                        <i class="fas fa-sign-in-alt"></i>
                    </span>

                    <span class="nav-link-inner--text">Inloggen</span>
                </a>
            </li>

            <li class="nav-item ml-1" v-if="pageType === 'dws'">
                <a @click="signUpCompany" class="btn btn-success btn-icon text-white">
                    <span class="btn-inner--icon">
                        <i class="fas fa-paw"></i>
                    </span>

                    <span class="nav-link-inner--text">Meld je aan</span>
                </a>
            </li>
        </ul>
    </nav>
</template>

<script>
module.exports = {
    data() {
        return {
            pageType: '',
            logoHref: '',
            dogServiceMenuItems: [
                {
                    title: 'Hoe werkt het', href: '/hondenbedrijf/zo-werkt-het', id: 'menu-how-it-works', submenuItems: [
                        { title: 'Zo werkt het', href: '/hondenbedrijf/zo-werkt-het', isMainItem: true, icon: 'fa fa-rocket' },
                        { title: 'Planning', href: '/hondenbedrijf/zo-werkt-het/planning', icon: 'fa fa-calendar' },
                        { title: 'Logistiek', href: '/hondenbedrijf/zo-werkt-het/logistiek', icon: 'fa fa-truck' },
                        { title: 'Facturatie', href: '/hondenbedrijf/zo-werkt-het/facturatie', icon: 'fa fa-dollar-sign' },
                        { title: 'DoggyDoggy App', href: '/hondenbedrijf/zo-werkt-het/app', icon: 'fas fa-mobile' },
                    ]
                },
                {
                    title: 'Voor wie', href: '/hondenbedrijf/voor-wie', id: 'menu-who', submenuItems: [
                        { title: 'Doelgroep', href: '/hondenbedrijf/voor-wie', isMainItem: true, icon: 'fas fa-users' },
                        { title: 'Hondenuitlaatservices', href: '/hondenbedrijf/voor-wie/hondenuitlaatservice', icon: 'fa fa-dog' },
                        { title: 'Hondenopvang', href: '/hondenbedrijf/voor-wie/hondenopvang', icon: 'fas fa-home' },
                        { title: 'Hondenschool', href: '/hondenbedrijf/voor-wie/hondenschool', icon: 'fas fa-school' },
                    ]
                },
                {
                    title: 'Prijsmodel', href: '/hondenbedrijf/prijsmodel', id: 'pricingmodel'
                },
                {
                    title: 'Meer weten', href: '/hondenbedrijf/meer-weten', id: 'menu-know-more', submenuItems: [
                        { title: 'Ik wil meer weten', href: '/hondenbedrijf/meer-weten', isMainItem: true, icon: 'fas fa-info-circle' },
                        { title: 'Demo', href: '/hondenbedrijf/meer-weten/demo', icon: 'fas fa-video' },
                        { title: 'Veelgestelde vragen', href: '/hondenbedrijf/meer-weten/veelgestelde-vragen', icon: 'fas fa-question' },
                        { title: 'Reviews', href: '/hondenbedrijf/meer-weten/reviews', icon: 'fa fa-star' },
                        { title: 'Blog', href: '/hondenbedrijf/meer-weten/blog', icon: 'fas fa-newspaper' },
                        { title: 'Buddy programma', href: '/hondenbedrijf/meer-weten/buddyprogramma', icon: 'fas fa-user-plus' },
                    ]
                },
                {
                    title: 'Over', href: '/hondenbedrijf/over', id: 'about'
                },
                {
                    title: 'Contact', href: '/hondenbedrijf/contact', id: 'contact'
                },
            ],
            endUserMenuItems: [
                {
                    title: 'Hoe werkt het', href: '/hondeneigenaar/zo-werkt-het', id: 'menu-how-it-works',
                },
                {
                    title: 'Meer weten', href: '/hondeneigenaar/meer-weten', id: 'menu-know-more', submenuItems: [
                        { title: 'Ik wil meer weten', href: '/hondeneigenaar/meer-weten', isMainItem: true, icon: 'fas fa-info-circle' },
                        { title: 'Veelgestelde vragen', href: '/hondeneigenaar/meer-weten/veelgestelde-vragen', icon: 'fas fa-question' },
                        { title: 'Blog', href: '/hondeneigenaar/meer-weten/blog', icon: 'fas fa-newspaper' },
                        { title: 'Over ons', href: '/hondeneigenaar/meer-weten/over', icon: 'fas fa-info-circle' },
                    ]
                },
                {
                    title: 'Zoeken', href: '/hondeneigenaar/zoeken', id: 'menu-search-company',
                },
            ],
            isLoadingUser: false,
        }
    },
    computed: {},
    methods: {
        changeUserType() {
            localStorage.userType = this.pageType === 'dws' ? 'enduser' : 'dws';
            window.location = this.pageType === 'dws' ? '/hondeneigenaar' : '/hondenbedrijf';
        },
        signUpCompany() {
            isLoadingUser = true;

            fetch('/user/account')
                .then((response) => {
                    // Check if the response is okay and parse it to JSON

                    return response?.json();
                })
                .then((data) => {
                    if (data?.user) {
                        window.location = '/companysignup';
                        return;
                    }

                    window.location = '/loginpage?signup=true';
                })
                .catch((error) => {
                    window.location = '/loginpage?signup=true';
                })
                .finally(() => {
                    this.isLoadingUser = false;
                });
        }
    },
    components: {
    },
    watch: {},
    created() {
        this.pageType = window.location.href.includes('hondenbedrijf') ? 'dws' : window.location.href.includes('hondeneigenaar') ? 'enduser' : '';
        this.menuItems = this.pageType === 'dws' ? this.dogServiceMenuItems : this.pageType === 'enduser' ? this.endUserMenuItems : [];
        this.logoHref = this.pageType === 'dws' ? '/hondenbedrijf' : this.pageType === 'enduser' ? '/hondeneigenaar' : '';
    },
    mounted() {
        const parent = location.pathname.split('/')[1] + '/' + location.pathname.split('/')[2];
        const parentElements = document.querySelectorAll("a[href='/" + parent + "']");

        parentElements.forEach(parentElement => {
            if (parentElement && !parentElement.classList.contains('active') && !parentElement.dataset.mainItem) {
                parentElement.classList.add('active');
            }
        });

        var els = document.querySelectorAll("a[href='" + location.pathname + "']");

        els.forEach(el => {
            el.classList.add('active');
        });
    }
}
</script>

<style scoped>
.navbar-nav li:hover .dropdown-menu {
    display: block;
    opacity: 100;
}

.navbar-nav .dropdown-menu::before {
    background-color: transparent;
}

.navbar-nav .dropdown-menu {
    pointer-events: all;
}

.bg-primary .dropdown-menu .dropdown-item:hover {
    background-color: transparent;
    text-decoration: underline;
}

.navbar {
    border: 0;
    z-index: 999;
}

.navbar-brand>img {
    height: 45px !important;
    max-width: 100%;
    aspect-ratio: 4.69;
}

@media (max-width: 991.98px) {
    #navbarNav {
        max-height: 100vh;
        overflow-y: auto;
        width: 100%;
        margin: 0;
    }
}

.submenu-icon {
    width: 20px;
}

.active>div>p,
.active>p {
    font-weight: bold;
}

.dropdown-item.active,
.dropdown-item:active {
    background-color: transparent;
    text-decoration: solid;
    color: black;
    font-weight: bold;
}

.menu-close-button:hover {
    background-color: var(--light);
    cursor: pointer;
    color: white;
}
</style>